package com.kingdee.eas.custom.esign;

import com.kingdee.bos.BOSException;
//import com.kingdee.bos.metadata.*;
import com.kingdee.bos.framework.*;
import com.kingdee.bos.util.*;
import com.kingdee.bos.Context;

import com.kingdee.bos.util.*;
import com.kingdee.eas.framework.ICoreBillEntryBase;
import com.kingdee.eas.framework.CoreBaseInfo;
import com.kingdee.bos.Context;
import com.kingdee.bos.dao.IObjectPK;
import com.kingdee.bos.BOSException;
import com.kingdee.bos.metadata.entity.FilterInfo;
import com.kingdee.bos.metadata.entity.SelectorItemCollection;
import com.kingdee.bos.metadata.entity.SorterItemCollection;
import com.kingdee.eas.common.EASBizException;
import com.kingdee.eas.framework.CoreBaseCollection;
import com.kingdee.bos.metadata.entity.EntityViewInfo;
import java.lang.String;
import com.kingdee.bos.framework.*;

public interface IESignTemplateFileEntry extends ICoreBillEntryBase
{
    public boolean exists(IObjectPK pk) throws BOSException, EASBizException;
    public boolean exists(FilterInfo filter) throws BOSException, EASBizException;
    public boolean exists(String oql) throws BOSException, EASBizException;
    public ESignTemplateFileEntryInfo getESignTemplateFileEntryInfo(IObjectPK pk) throws BOSException, EASBizException;
    public ESignTemplateFileEntryInfo getESignTemplateFileEntryInfo(IObjectPK pk, SelectorItemCollection selector) throws BOSException, EASBizException;
    public ESignTemplateFileEntryInfo getESignTemplateFileEntryInfo(String oql) throws BOSException, EASBizException;
    public IObjectPK addnew(ESignTemplateFileEntryInfo model) throws BOSException, EASBizException;
    public void addnew(IObjectPK pk, ESignTemplateFileEntryInfo model) throws BOSException, EASBizException;
    public void update(IObjectPK pk, ESignTemplateFileEntryInfo model) throws BOSException, EASBizException;
    public void updatePartial(ESignTemplateFileEntryInfo model, SelectorItemCollection selector) throws BOSException, EASBizException;
    public void updateBigObject(IObjectPK pk, ESignTemplateFileEntryInfo model) throws BOSException;
    public void delete(IObjectPK pk) throws BOSException, EASBizException;
    public IObjectPK[] getPKList() throws BOSException, EASBizException;
    public IObjectPK[] getPKList(String oql) throws BOSException, EASBizException;
    public IObjectPK[] getPKList(FilterInfo filter, SorterItemCollection sorter) throws BOSException, EASBizException;
    public ESignTemplateFileEntryCollection getESignTemplateFileEntryCollection() throws BOSException;
    public ESignTemplateFileEntryCollection getESignTemplateFileEntryCollection(EntityViewInfo view) throws BOSException;
    public ESignTemplateFileEntryCollection getESignTemplateFileEntryCollection(String oql) throws BOSException;
    public IObjectPK[] delete(FilterInfo filter) throws BOSException, EASBizException;
    public IObjectPK[] delete(String oql) throws BOSException, EASBizException;
    public void delete(IObjectPK[] arrayPK) throws BOSException, EASBizException;
    public void syncTemplateFields(String entryId) throws BOSException, EASBizException;
    public void syncSuccess(String entryId, String syncResult) throws BOSException, EASBizException;
    public void syncFail(String syncResult, String entryid) throws BOSException, EASBizException;
    public String findByFileName(String fileName) throws BOSException, EASBizException;
}